CMIP6 institution_id values
Author: Paul J. Durack
Description: Controlled vocabulary for CMIP6
Keywords: HTML, CSS, JavaScript

# WCRP-CMIP CMIP6_CVs version: 6.2.60.0

#### Experiment IDs | Institution IDs | Source IDs | Source IDs (incl licenses) | Citations by (Source ID, Institution Id, Activity ID) | Citations by (Source ID, Institution Id, Activity ID, Experiment ID) |

institution_id | Description
--- | ---
institution_id | Description
AER | Research and Climate Group, Atmospheric and Environmental Research, 131 Hartwell Avenue, Lexington, MA 02421, USA
AS-RCEC | Research Center for Environmental Changes, Academia Sinica, Nankang, Taipei 11529, Taiwan
AWI | Alfred Wegener Institute, Helmholtz Centre for Polar and Marine Research, Am Handelshafen 12, 27570 Bremerhaven, Germany
BCC | Beijing Climate Center, Beijing 100081, China
CAMS | Chinese Academy of Meteorological Sciences, Beijing 100081, China
CAS | Chinese Academy of Sciences, Beijing 100029, China
CCCR-IITM | Centre for Climate Change Research, Indian Institute of Tropical Meteorology Pune, Maharashtra 411 008, India
CCCma | Canadian Centre for Climate Modelling and Analysis, Environment and Climate Change Canada, Victoria, BC V8P 5C2, Canada
CMCC | Fondazione Centro Euro-Mediterraneo sui Cambiamenti Climatici, Lecce 73100, Italy
CNRM-CERFACS | CNRM (Centre National de Recherches Meteorologiques, Toulouse 31057, France), CERFACS (Centre Europeen de Recherche et de Formation Avancee en Calcul Scientifique, Toulouse 31057, France)
CSIRO | Commonwealth Scientific and Industrial Research Organisation, Aspendale, Victoria 3195, Australia
CSIRO-ARCCSS | CSIRO (Commonwealth Scientific and Industrial Research Organisation, Aspendale, Victoria 3195, Australia), ARCCSS (Australian Research Council Centre of Excellence for Climate System Science). Mailing address: CSIRO, c/o Simon J. Marsland, 107-121 Station Street, Aspendale, Victoria 3195, Australia
CSIRO-COSIMA | CSIRO (Commonwealth Scientific and Industrial Research Organisation, Australia), COSIMA (Consortium for Ocean-Sea Ice Modelling in Australia). Mailing address: CSIRO, c/o Simon J. Marsland, 107-121 Station Street, Aspendale, Victoria 3195, Australia
DKRZ | Deutsches Klimarechenzentrum, Hamburg 20146, Germany
DWD | Deutscher Wetterdienst, Offenbach am Main 63067, Germany
E3SM-Project | LLNL (Lawrence Livermore National Laboratory, Livermore, CA 94550, USA); ANL (Argonne National Laboratory, Argonne, IL 60439, USA); BNL (Brookhaven National Laboratory, Upton, NY 11973, USA); LANL (Los Alamos National Laboratory, Los Alamos, NM 87545, USA); LBNL (Lawrence Berkeley National Laboratory, Berkeley, CA 94720, USA); ORNL (Oak Ridge National Laboratory, Oak Ridge, TN 37831, USA); PNNL (Pacific Northwest National Laboratory, Richland, WA 99352, USA); SNL (Sandia National Laboratories, Albuquerque, NM 87185, USA). Mailing address: LLNL Climate Program, c/o David C. Bader, Principal Investigator, L-103, 7000 East Avenue, Livermore, CA 94550, USA
EC-Earth-Consortium | AEMET, Spain; BSC, Spain; CNR-ISAC, Italy; DMI, Denmark; ENEA, Italy; FMI, Finland; Geomar, Germany; ICHEC, Ireland; ICTP, Italy; IDL, Portugal; IMAU, The Netherlands; IPMA, Portugal; KIT, Karlsruhe, Germany; KNMI, The Netherlands; Lund University, Sweden; Met Eireann, Ireland; NLeSC, The Netherlands; NTNU, Norway; Oxford University, UK; surfSARA, The Netherlands; SMHI, Sweden; Stockholm University, Sweden; Unite ASTR, Belgium; University College Dublin, Ireland; University of Bergen, Norway; University of Copenhagen, Denmark; University of Helsinki, Finland; University of Santiago de Compostela, Spain; Uppsala University, Sweden; Utrecht University, The Netherlands; Vrije Universiteit Amsterdam, the Netherlands; Wageningen University, The Netherlands. Mailing address: EC-Earth consortium, Rossby Center, Swedish Meteorological and Hydrological Institute/SMHI, SE-601 76 Norrkoping, Sweden
ECMWF | European Centre for Medium-Range Weather Forecasts, Reading RG2 9AX, UK
FIO-QLNM | FIO (First Institute of Oceanography, Ministry of Natural Resources, Qingdao 266061, China), QNLM (Qingdao National Laboratory for Marine Science and Technology, Qingdao 266237, China)
HAMMOZ-Consortium | ETH Zurich, Switzerland; Max Planck Institut fur Meteorologie, Germany; Forschungszentrum Julich, Germany; University of Oxford, UK; Finnish Meteorological Institute, Finland; Leibniz Institute for Tropospheric Research, Germany; Center for Climate Systems Modeling (C2SM) at ETH Zurich, Switzerland
INM | Institute for Numerical Mathematics, Russian Academy of Science, Moscow 119991, Russia
IPSL | Institut Pierre Simon Laplace, Paris 75252, France
KIOST | Korea Institute of Ocean Science and Technology, Busan 49111, Republic of Korea
LLNL | Lawrence Livermore National Laboratory, Livermore, CA 94550, USA. Mailing address: LLNL Climate Program, c/o Stephen A. Klein, Principal Investigator, L-103, 7000 East Avenue, Livermore, CA 94550, USA
MESSy-Consortium | The Modular Earth Submodel System (MESSy) Consortium, represented by the Institute for Physics of the Atmosphere, Deutsches Zentrum fur Luft- und Raumfahrt (DLR), Wessling, Bavaria 82234, Germany
MIROC | JAMSTEC (Japan Agency for Marine-Earth Science and Technology, Kanagawa 236-0001, Japan), AORI (Atmosphere and Ocean Research Institute, The University of Tokyo, Chiba 277-8564, Japan), NIES (National Institute for Environmental Studies, Ibaraki 305-8506, Japan), and R-CCS (RIKEN Center for Computational Science, Hyogo 650-0047, Japan)
MOHC | Met Office Hadley Centre, Fitzroy Road, Exeter, Devon, EX1 3PB, UK
MPI-M | Max Planck Institute for Meteorology, Hamburg 20146, Germany
MRI | Meteorological Research Institute, Tsukuba, Ibaraki 305-0052, Japan
NASA-GISS | Goddard Institute for Space Studies, New York, NY 10025, USA
NASA-GSFC | NASA Goddard Space Flight Center, Greenbelt, MD 20771, USA
NCAR | National Center for Atmospheric Research, Climate and Global Dynamics Laboratory, 1850 Table Mesa Drive, Boulder, CO 80305, USA
NCC | NorESM Climate modeling Consortium consisting of CICERO (Center for International Climate and Environmental Research, Oslo 0349), MET-Norway (Norwegian Meteorological Institute, Oslo 0313), NERSC (Nansen Environmental and Remote Sensing Center, Bergen 5006), NILU (Norwegian Institute for Air Research, Kjeller 2027), UiB (University of Bergen, Bergen 5007), UiO (University of Oslo, Oslo 0313) and UNI (Uni Research, Bergen 5008), Norway. Mailing address: NCC, c/o MET-Norway, Henrik Mohns plass 1, Oslo 0313, Norway
NERC | Natural Environment Research Council, STFC-RAL, Harwell, Oxford, OX11 0QX, UK
NIMS-KMA | National Institute of Meteorological Sciences/Korea Meteorological Administration, Climate Research Division, Seoho-bukro 33, Seogwipo-si, Jejudo 63568, Republic of Korea
NIWA | National Institute of Water and Atmospheric Research, Hataitai, Wellington 6021, New Zealand
NOAA-GFDL | National Oceanic and Atmospheric Administration, Geophysical Fluid Dynamics Laboratory, Princeton, NJ 08540, USA
NTU | National Taiwan University, Taipei 10650, Taiwan
NUIST | Nanjing University of Information Science and Technology, Nanjing, 210044, China
PCMDI | Program for Climate Model Diagnosis and Intercomparison, Lawrence Livermore National Laboratory, Livermore, CA 94550, USA
PNNL-WACCEM | PNNL (Pacific Northwest National Laboratory), Richland, WA 99352, USA
RTE-RRTMGP-Consortium | AER (Atmospheric and Environmental Research, Lexington, MA 02421, USA); UColorado (University of Colorado, Boulder, CO 80309, USA). Mailing address: AER c/o Eli Mlawer, 131 Hartwell Avenue, Lexington, MA 02421, USA
RUBISCO | ORNL (Oak Ridge National Laboratory, Oak Ridge, TN 37831, USA); ANL (Argonne National Laboratory, Argonne, IL 60439, USA); BNL (Brookhaven National Laboratory, Upton, NY 11973, USA); LANL (Los Alamos National Laboratory, Los Alamos, NM 87545); LBNL (Lawrence Berkeley National Laboratory, Berkeley, CA 94720, USA); NAU (Northern Arizona University, Flagstaff, AZ 86011, USA); NCAR (National Center for Atmospheric Research, Boulder, CO 80305, USA); UCI (University of California Irvine, Irvine, CA 92697, USA); UM (University of Michigan, Ann Arbor, MI 48109, USA). Mailing address: ORNL Climate Change Science Institute, c/o Forrest M. Hoffman, Laboratory Research Manager, Building 4500N Room F106, 1 Bethel Valley Road, Oak Ridge, TN 37831-6301, USA
SNU | Seoul National University, Seoul 08826, Republic of Korea
THU | Department of Earth System Science, Tsinghua University, Beijing 100084, China
UA | Department of Geosciences, University of Arizona, Tucson, AZ 85721, USA
UCI | Department of Earth System Science, University of California Irvine, Irvine, CA 92697, USA
UCSB | Bren School of Environmental Science and Management, University of California, Santa Barbara. Mailing address: c/o Samantha Stevenson, 2400 Bren Hall, University of California Santa Barbara, Santa Barbara, CA 93106, USA
UHH | Universitat Hamburg, Hamburg 20148, Germany